==> zzyj-outputvalcount-api-3.0.0-20230525.061906-170-sources.jar: com/ejianc/business/outputvalcount/hyxtrix/OutputValueHystrix.java <==
package com.ejianc.business.outputvalcount.hyxtrix;

import com.ejianc.business.outputvalcount.api.IOutputValueApi;
import com.ejianc.business.outputvalcount.vo.OutputValDTO;
import com.ejianc.business.outputvalcount.vo.OutputValueVO;
import com.ejianc.business.outputvalcount.vo.ProjectDetailDTO;
import com.ejianc.business.outputvalcount.vo.XmyxglVO;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.stereotype.Component;

import javax.servlet.http.HttpServletRequest;
import java.math.BigDecimal;
import java.util.HashMap;
import java.util.List;

@Component
public class OutputValueHystrix implements IOutputValueApi {


    @Override
    public CommonResponse<List<ProjectDetailDTO>> getOutputValue(HttpServletRequest request) {
        return CommonResponse.error("网络问题， 查询失败。");
    }

    @Override
    public CommonResponse<OutputValueVO> getSumByProjectId(Long projectId) {
        return CommonResponse.error("网络问题， 查询失败。");
    }

    @Override
    public CommonResponse<List<XmyxglVO>> getInfoByProjectId(Long projectId,Integer num) {
        return CommonResponse.error("网络问题， 查询失败。");
    }

    @Override
    public CommonResponse<OutputValueVO> getSumByOrgId(Long orgId) {
        return CommonResponse.error("网络问题， 查询失败。");
    }

    @Override
    public CommonResponse<BigDecimal> getSumByOrgIdUnder(Long orgId,Integer year) {
        return CommonResponse.error("网络问题， 查询失败。");
    }

    @Override
    public CommonResponse<HashMap<Long, BigDecimal>> getSumByOrgIds(OutputValDTO dto) {
        return CommonResponse.error("网络问题， 查询失败。");
    }
}

==> zzyj-outputvalcount-api-3.0.0-20240626.080659-308-sources.jar: com/ejianc/business/outputvalcount/hyxtrix/OutputValueHystrix.java <==
package com.ejianc.business.outputvalcount.hyxtrix;

import com.ejianc.business.outputvalcount.api.IOutputValueApi;
import com.ejianc.business.outputvalcount.vo.*;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.stereotype.Component;

import javax.servlet.http.HttpServletRequest;
import java.math.BigDecimal;
import java.util.HashMap;
import java.util.List;

@Component
public class OutputValueHystrix implements IOutputValueApi {


    @Override
    public CommonResponse<List<ProjectDetailDTO>> getOutputValue(HttpServletRequest request) {
        return CommonResponse.error("网络问题， 查询失败。");
    }

    @Override
    public CommonResponse<OutputValueVO> getSumByProjectId(Long projectId) {
        return CommonResponse.error("网络问题， 查询失败。");
    }

    @Override
    public CommonResponse<List<XmyxglVO>> getInfoByProjectId(Long projectId,Integer num) {
        return CommonResponse.error("网络问题， 查询失败。");
    }

    @Override
    public CommonResponse<OutputValueVO> getSumByOrgId(Long orgId) {
        return CommonResponse.error("网络问题， 查询失败。");
    }

    @Override
    public CommonResponse<BigDecimal> getSumByOrgIdUnder(Long orgId,Integer year) {
        return CommonResponse.error("网络问题， 查询失败。");
    }

    @Override
    public CommonResponse<HashMap<Long, BigDecimal>> getSumByOrgIds(OutputValDTO dto) {
        return CommonResponse.error("网络问题， 查询失败。");
    }

    @Override
    public CommonResponse<MonthlyStatisticsVO> getProjectDeatilByProjectId(Long projectId) {
        return  CommonResponse.error("网络问题， 查询失败。");
    }
}
